@@ -26,6 +26,9 @@ class Partner:
         sponsor_id,
         coop_candidate,
         member,
+        sponsorship_code,
+        sponsees_max,
+        sponsees_number,
         **kwargs
     ):
         self.id = id
@@ -45,6 +48,9 @@ class Partner:
         self.coop_agreement_code = coop_agreement_code
         self.coop_candidate = coop_candidate
         self.member = member
+        self.sponsorship_code = sponsorship_code
+        self.sponsees_max = sponsees_max
+        self.sponsees_number = sponsees_number
 
     @classmethod
     def get(cls, ref):
