@@ -23,11 +23,11 @@ class ProductCatalog:
         self.products = [Product(**product) for product in products]
 
     @classmethod
-    def search(cls, code="", category="", lang="ca"):
+    def search(cls, code="", category="", lang="ca", product_code=""):
         headers = {'Accept-Language': lang}
         response_data = Client().get(
             "{}".format(cls._url_path),
-            params={"code": code, "categ": category},
+            params={"code": code, "categ": category, "product_code": product_code},
             extra_headers=headers
         )
 
