@@ -75,3 +75,22 @@ class TariffTests(unittest.TestCase):
             "Ilimitadas 10 GB",
             es_product_names
         )
+
+    @pytest.mark.vcr()
+    def test_search_available_products_for_product_code(self):
+        """ For product fibra 100Mb only are available other Fiber products. """
+        pricelists = ProductCatalog.search(product_code="SE_SC_REC_BA_F_100")
+        product_codes = [p.code for p in pricelists[0].products]
+
+        self.assertIn(
+            "SE_SC_REC_BA_F_1024",
+            product_codes
+        )
+        self.assertIn(
+            "SE_SC_REC_BA_F_600",
+            product_codes
+        )
+        self.assertNotIn(
+            "SE_SC_REC_BA_ADSL_SF",
+            product_codes
+        )
